==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/HorizontalRangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RangeCategorySeriesDescriptionMetadata } from "./RangeCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var HorizontalRangeCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HorizontalRangeCategorySeriesDescriptionMetadata, _super);
    function HorizontalRangeCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalRangeCategorySeriesDescriptionMetadata.b = function (a) {
        if (HorizontalRangeCategorySeriesDescriptionMetadata.a == null) {
            HorizontalRangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HorizontalRangeCategorySeriesDescriptionMetadata.c(HorizontalRangeCategorySeriesDescriptionMetadata.a);
        }
        if (a.g(HorizontalRangeCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(HorizontalRangeCategorySeriesDescriptionMetadata.a);
    };
    HorizontalRangeCategorySeriesDescriptionMetadata.c = function (a) {
        RangeCategorySeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("LowMemberAsLegendLabel", "String");
        a.item("HighMemberAsLegendLabel", "String");
        a.item("LowMemberAsLegendUnit", "String");
        a.item("HighMemberAsLegendUnit", "String");
    };
    HorizontalRangeCategorySeriesDescriptionMetadata.d = function (a) {
        HorizontalRangeCategorySeriesDescriptionMetadata.b(a);
        a.t("HorizontalRangeCategorySeries", HorizontalRangeCategorySeriesDescriptionMetadata.a);
    };
    HorizontalRangeCategorySeriesDescriptionMetadata.$t = markType(HorizontalRangeCategorySeriesDescriptionMetadata, 'HorizontalRangeCategorySeriesDescriptionMetadata');
    HorizontalRangeCategorySeriesDescriptionMetadata.a = null;
    return HorizontalRangeCategorySeriesDescriptionMetadata;
}(Base));
export { HorizontalRangeCategorySeriesDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/HorizontalRangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RangeCategorySeriesDescriptionMetadata } from "./RangeCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var HorizontalRangeCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HorizontalRangeCategorySeriesDescriptionMetadata, _super);
    function HorizontalRangeCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalRangeCategorySeriesDescriptionMetadata.b = function (a) {
        if (HorizontalRangeCategorySeriesDescriptionMetadata.a == null) {
            HorizontalRangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HorizontalRangeCategorySeriesDescriptionMetadata.c(HorizontalRangeCategorySeriesDescriptionMetadata.a);
        }
        if (a.j(HorizontalRangeCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(HorizontalRangeCategorySeriesDescriptionMetadata.a);
    };
    HorizontalRangeCategorySeriesDescriptionMetadata.c = function (a) {
        RangeCategorySeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("LowMemberAsLegendLabel", "String");
        a.item("HighMemberAsLegendLabel", "String");
        a.item("LowMemberAsLegendUnit", "String");
        a.item("HighMemberAsLegendUnit", "String");
    };
    HorizontalRangeCategorySeriesDescriptionMetadata.d = function (a) {
        HorizontalRangeCategorySeriesDescriptionMetadata.b(a);
        a.z("HorizontalRangeCategorySeries", HorizontalRangeCategorySeriesDescriptionMetadata.a);
    };
    HorizontalRangeCategorySeriesDescriptionMetadata.$t = markType(HorizontalRangeCategorySeriesDescriptionMetadata, 'HorizontalRangeCategorySeriesDescriptionMetadata');
    HorizontalRangeCategorySeriesDescriptionMetadata.a = null;
    return HorizontalRangeCategorySeriesDescriptionMetadata;
}(Base));
export { HorizontalRangeCategorySeriesDescriptionMetadata };
